
/* Generated data (by glib-mkenums) */

#ifndef _GRL_TYPE_BUILTINS_H_
#define _GRL_TYPE_BUILTINS_H_

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "grl-source.h" */
GType grl_supported_ops_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_SUPPORTED_OPS (grl_supported_ops_get_type())
GType grl_source_change_type_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_SOURCE_CHANGE_TYPE (grl_source_change_type_get_type())

/* enumerations from "grl-caps.h" */
GType grl_type_filter_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_TYPE_FILTER (grl_type_filter_get_type())

/* enumerations from "grl-operation-options.h" */
GType grl_resolution_flags_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_RESOLUTION_FLAGS (grl_resolution_flags_get_type())
GType grl_write_flags_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_WRITE_FLAGS (grl_write_flags_get_type())

/* enumerations from "data/grl-media.h" */
GType grl_media_serialize_type_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_MEDIA_SERIALIZE_TYPE (grl_media_serialize_type_get_type())
GType grl_media_type_get_type (void) G_GNUC_CONST;
#define GRL_TYPE_MEDIA_TYPE (grl_media_type_get_type())
G_END_DECLS

#endif /* _GRL_TYPE_BUILTINS_H_ */

/* Generated data ends here */

